@@ -259,14 +259,10 @@ class _File extends FileSystemEntity implements File {
   final String _path;
   final Uint8List _rawPath;
 
-  _File(String path)
-    : _path = _checkNotNull(path, "path"),
-      _rawPath = FileSystemEntity._toUtf8Array(path);
+  _File(this._path) : _rawPath = FileSystemEntity._toUtf8Array(_path);
 
   _File.fromRawPath(Uint8List rawPath)
-    : _rawPath = FileSystemEntity._toNullTerminatedUtf8Array(
-        _checkNotNull(rawPath, "rawPath"),
-      ),
+    : _rawPath = FileSystemEntity._toNullTerminatedUtf8Array(rawPath),
       _path = FileSystemEntity._toStringFromUtf8Array(rawPath);
 
   String get path => _path;
@@ -783,12 +779,6 @@ class _File extends FileSystemEntity implements File {
       throw FileSystemException._fromOSError(result, msg, path);
     }
   }
-
-  // TODO(40614): Remove once non-nullability is sound.
-  static T _checkNotNull<T>(T t, String name) {
-    ArgumentError.checkNotNull(t, name);
-    return t;
-  }
 }
 
 abstract class _RandomAccessFileOps {
@@ -894,8 +884,6 @@ class _RandomAccessFile implements RandomAccessFile {
   }
 
   Future<Uint8List> read(int bytes) {
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(bytes, "bytes");
     return _dispatch(_IOService.fileRead, [null, bytes]).then((response) {
       _checkForErrorResponse(response, "read failed", path);
       var result = (response as List<Object?>)[1] as Uint8List;
@@ -905,8 +893,6 @@ class _RandomAccessFile implements RandomAccessFile {
   }
 
   Uint8List readSync(int bytes) {
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(bytes, "bytes");
     _checkAvailable();
     var result = _ops.read(bytes);
     if (result is! Uint8List) {
@@ -917,8 +903,6 @@ class _RandomAccessFile implements RandomAccessFile {
   }
 
   Future<int> readInto(List<int> buffer, [int start = 0, int? end]) {
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(buffer, "buffer");
     end = RangeError.checkValidRange(start, end, buffer.length);
     if (end == start) {
       return new Future.value(0);
@@ -936,8 +920,6 @@ class _RandomAccessFile implements RandomAccessFile {
   }
 
   int readIntoSync(List<int> buffer, [int start = 0, int? end]) {
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(buffer, "buffer");
     _checkAvailable();
     end = RangeError.checkValidRange(start, end, buffer.length);
     if (end == start) {
@@ -952,8 +934,6 @@ class _RandomAccessFile implements RandomAccessFile {
   }
 
   Future<RandomAccessFile> writeByte(int value) {
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(value, "value");
     return _dispatch(_IOService.fileWriteByte, [null, value]).then((response) {
       _checkForErrorResponse(response, "writeByte failed", path);
       _resourceInfo.addWrite(1);
@@ -963,8 +943,6 @@ class _RandomAccessFile implements RandomAccessFile {
 
   int writeByteSync(int value) {
     _checkAvailable();
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(value, "value");
     var result = _ops.writeByte(value);
     if (result is OSError) {
       throw new FileSystemException("writeByte failed", path, result);
@@ -978,9 +956,6 @@ class _RandomAccessFile implements RandomAccessFile {
     int start = 0,
     int? end,
   ]) {
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(buffer, "buffer");
-    ArgumentError.checkNotNull(start, "start");
     end = RangeError.checkValidRange(start, end, buffer.length);
     if (end == start) {
       return new Future.value(this);
@@ -1006,9 +981,6 @@ class _RandomAccessFile implements RandomAccessFile {
 
   void writeFromSync(List<int> buffer, [int start = 0, int? end]) {
     _checkAvailable();
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(buffer, "buffer");
-    ArgumentError.checkNotNull(start, "start");
     end = RangeError.checkValidRange(start, end, buffer.length);
     if (end == start) {
       return;
@@ -1033,15 +1005,11 @@ class _RandomAccessFile implements RandomAccessFile {
     String string, {
     Encoding encoding = utf8,
   }) {
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(encoding, "encoding");
     var data = encoding.encode(string);
     return writeFrom(data, 0, data.length);
   }
 
   void writeStringSync(String string, {Encoding encoding = utf8}) {
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(encoding, "encoding");
     var data = encoding.encode(string);
     writeFromSync(data, 0, data.length);
   }
@@ -1138,10 +1106,6 @@ class _RandomAccessFile implements RandomAccessFile {
     int start = 0,
     int end = -1,
   ]) {
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(mode, "mode");
-    ArgumentError.checkNotNull(start, "start");
-    ArgumentError.checkNotNull(end, "end");
     if ((start < 0) || (end < -1) || ((end != -1) && (start >= end))) {
       throw new ArgumentError();
     }
@@ -1155,9 +1119,6 @@ class _RandomAccessFile implements RandomAccessFile {
   }
 
   Future<RandomAccessFile> unlock([int start = 0, int end = -1]) {
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(start, "start");
-    ArgumentError.checkNotNull(end, "end");
     if (start == end) {
       throw new ArgumentError();
     }
@@ -1175,10 +1136,6 @@ class _RandomAccessFile implements RandomAccessFile {
     int end = -1,
   ]) {
     _checkAvailable();
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(mode, "mode");
-    ArgumentError.checkNotNull(start, "start");
-    ArgumentError.checkNotNull(end, "end");
     if ((start < 0) || (end < -1) || ((end != -1) && (start >= end))) {
       throw new ArgumentError();
     }
@@ -1191,9 +1148,6 @@ class _RandomAccessFile implements RandomAccessFile {
 
   void unlockSync([int start = 0, int end = -1]) {
     _checkAvailable();
-    // TODO(40614): Remove once non-nullability is sound.
-    ArgumentError.checkNotNull(start, "start");
-    ArgumentError.checkNotNull(end, "end");
     if (start == end) {
       throw new ArgumentError();
     }
